"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _lang = require("../lang");

var _evaluateConfigAndEnv2 = _interopRequireDefault(require("./util/evaluateConfigAndEnv"));

var _getStage = _interopRequireDefault(require("./util/getStage"));

var _getTarget = _interopRequireDefault(require("./util/getTarget"));

var _updateEnv = _interopRequireDefault(require("./util/updateEnv"));

var _validateConfig = _interopRequireDefault(require("./util/validateConfig"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// TODO: Split this function into different versions based on ios, android and web
// import env from 'react-native-config'
var loadConfigSync = (options = {}, initialConfig = {}, context = {}) => {
  var stage = (0, _getStage.default)(options);
  var target = (0, _getTarget.default)(options);
  initialConfig = (0, _lang.merge)({
    stage,
    target
  }, initialConfig);
  var config;
  var env;

  if (target === 'web') {
    // NOTE BRN: We can't use fs here to load files and we shouldn't load the yaml
    // files in because they have sensitive data. Instead the config should be
    // precompiled and then injected into process.env
    config = process.env.MOLTRES_CONFIG ? JSON.parse(process.env.MOLTRES_CONFIG) : {};
    env = process.env.MOLTRES_ENV ? JSON.parse(process.env.MOLTRES_ENV) : {};
  } else {
    // NOTE BRN: dynamically require the needed modules here so that we avoid
    // loading node specific modules in the web environment
    var _require = require('./util'),
        loadConfigFileSync = _require.loadConfigFileSync,
        loadDotEnvSync = _require.loadDotEnvSync;

    env = loadDotEnvSync(options);
    config = loadConfigFileSync(options);
    var cwd = options.cwd || process.cwd() // Load raw config and env and then resolve their values against
    // each other since they can cross reference each other
    ;

    var _evaluateConfigAndEnv = (0, _evaluateConfigAndEnv2.default)({
      config: (0, _lang.mergeDeepRight)(initialConfig, config || {}),
      env
    }, options, (0, _lang.mergeDeepRight)({
      project: {
        dir: cwd
      }
    }, context));

    config = _evaluateConfigAndEnv.config;
    env = _evaluateConfigAndEnv.env;
  }

  var modules = options.modules;

  if (modules) {
    (0, _validateConfig.default)(modules, config);
  }

  if (target !== 'web') {
    (0, _updateEnv.default)(env);
  }

  return config;
};

var _default = loadConfigSync;
exports.default = _default;
//# sourceMappingURL=loadConfigSync.js.map