"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _isEvaluable = _interopRequireDefault(require("./isEvaluable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Evaluates a value.
 *
 * Dispatches to the `evaluate` method if it exists. If an evaluate method returns
 * a value that is also evaluate, this method will evaluate that value as
 * well.
 *
 * @private
 * @function
 * @since v0.3.0
 * @category config.util
 * @param {*} any The value to evaluate.
 * @returns {*} The evaluated value.
 * @example
 *
 * evaluate('foo')
 * // => 'foo'
 *
 * evaluate({
 *  evaluate: () => 'bar'
 * })
 * //=> bar
 *
 * evaluate({
 *   evaluate: () => ({
 *     evaluate: () => 'bar'
 *   })
 * })
 * //=> bar
 */
var evaluate = (any, ...rest) => {
  if ((0, _isEvaluable.default)(any)) {
    return evaluate(any.evaluate(...rest), ...rest);
  }

  return any;
};

var _default = evaluate;
exports.default = _default;
//# sourceMappingURL=evaluate.js.map