"use strict";

require("core-js/modules/es.array.filter");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var lang = _interopRequireWildcard(require("../../lang"));

var path = _interopRequireWildcard(require("../../path"));

var _evaluate = _interopRequireDefault(require("./evaluate"));

var _getCwd = _interopRequireDefault(require("./getCwd"));

var _getStage = _interopRequireDefault(require("./getStage"));

var _getTarget = _interopRequireDefault(require("./getTarget"));

var _hasVariableString = _interopRequireDefault(require("./hasVariableString"));

var _isEvaluable = _interopRequireDefault(require("./isEvaluable"));

var _newVariable = _interopRequireDefault(require("./newVariable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var UTIL_METHODS = _objectSpread(_objectSpread({}, lang), path); // NOTE BRN: This step converts variable strings into variable objects.
// NOTE BRN: The data object should not have any cicular references so this
// should be safe to walk without infinite loops.


var isValueObject = value => (0, lang.isObject)(value) && (0, lang.hasProperty)('value', value);

var isSensitivePath = (pathParts, data) => {
  var index = 0;
  var currentPath = [];

  while (index < pathParts.length) {
    var part = pathParts[index];

    if (part === 'value') {
      var value = (0, lang.getPath)(currentPath, data);

      if (value.sensitive) {
        return true;
      }
    }

    currentPath = (0, lang.append)(part, currentPath);
    index += 1;
  }

  return false;
};

var enhanceData = (data, options) => (0, lang.walkReduceDepthFirst)((accum, value, pathParts) => {
  var lastPathPart = (0, lang.last)(pathParts);
  var parentValue = (0, lang.getParent)(pathParts, data); // NOTE BRN: We drop any path parts that are the key 'value' since those
  // are collapsed during this process.

  var collapsedPathParts = (0, lang.reject)((0, lang.equals)('value'), pathParts); // TODO BRN: Break this up into something that is pluggable by core so
  // that anyone can introduce new interpretable values.

  if ((0, lang.isObject)(value)) {
    return accum;
  }

  if (isValueObject(parentValue)) {
    if (lastPathPart !== 'value') {
      return accum;
    }
  }

  if (options.dropSensitive && isSensitivePath(pathParts, data)) {
    return accum;
  }

  if ((0, lang.isString)(value) && (0, _hasVariableString.default)(value)) {
    return (0, lang.assocPath)(collapsedPathParts, (0, _newVariable.default)(value), accum);
  }

  return (0, lang.assocPath)(collapsedPathParts, value, accum);
}, (0, lang.map)(() => ({}), data), data); // NOTE BRN: The data object coule have circular references within variables.


var evaluateData = (data, context) => {
  var result = (0, lang.walkReduceDepthFirst)((accum, value, pathParts) => {
    if ((0, _isEvaluable.default)(value)) {
      return (0, lang.assocPath)(pathParts, (0, _evaluate.default)(value, accum, context), accum);
    }

    return accum;
  }, data, data); // NOTE BRN: This allows for variables that refer to objects with variables to
  // be properly resolved.

  if (!(0, lang.equals)(data, result)) {
    return evaluateData(result, context);
  }

  return result;
};

var evaluateConfigAndEnv = (data, options = {}, context = {}) => {
  var cwd = (0, _getCwd.default)(options);
  var stage = (0, _getStage.default)(options);
  var target = (0, _getTarget.default)(options);
  var enhancedData = enhanceData(data, options);
  return (0, lang.pick)(['config', 'env'], evaluateData(_objectSpread(_objectSpread({}, enhancedData), {}, {
    this: enhancedData.config
  }), _objectSpread(_objectSpread({}, UTIL_METHODS), {}, {
    cwd,
    stage,
    target
  }, context)));
};

var _default = evaluateConfigAndEnv;
exports.default = _default;
//# sourceMappingURL=evaluateConfigAndEnv.js.map