"use strict";

require("core-js/modules/es.regexp.to-string");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _lang = require("../lang");

var _addTimestamps = _interopRequireDefault(require("./addTimestamps"));

var _collection = _interopRequireDefault(require("./collection"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Adds a document create to the given WriteBatch of the given Schema type with
 * the given data. Returns the DocumentReference of the document to be created
 * when the batch is commited.
 *
 * @function
 * @since v0.5.7
 * @category db
 * @param {Schema} Schema
 * @param {Context} context
 * @param {WriteBatch} batch
 * @param {Object} data
 * @returns {DocumentReference}
 */
var batchCreateDocument = (0, _lang.curry)((Schema, context, batch, data) => {
  var Collection = (0, _collection.default)(Schema, context, data);
  var idField = Schema.idField;
  var ref;

  if (!(0, _lang.isNil)(idField)) {
    if (idField !== 'id' && (0, _lang.hasProperty)('id', data)) {
      throw new Error("Cannot define 'id' field in 'data' when the idField is set to '".concat(idField, "'. This can only be done when 'idField' is not set or when it is set to 'id'"));
    }

    ref = Collection.doc((0, _lang.getProperty)(idField, data).toString());
  } else if ((0, _lang.hasProperty)('id', data)) {
    ref = Collection.doc(data.id.toString());
  } else {
    ref = Collection.doc();
  }

  batch.set(ref, (0, _addTimestamps.default)(context, data));
  return ref;
});
var _default = batchCreateDocument;
exports.default = _default;
//# sourceMappingURL=batchCreateDocument.js.map