"use strict";

require("core-js/modules/es.array.concat");

require("core-js/modules/es.array.filter");

require("core-js/modules/es.array.iterator");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/es.regexp.to-string");

require("core-js/modules/web.dom-collections.for-each");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _lang = require("../lang");

var _collection = _interopRequireDefault(require("./collection"));

var _getSchemaLineage = _interopRequireDefault(require("./getSchemaLineage"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Reference a document by id
 * @function
 * @since v0.5.7
 * @category db
 * @param {Schema} schema
 * @param {Context} context
 * @param {string|Array} ids
 * @returns {DocumentReference}
 */
var refDocumentById = (0, _lang.curry)((Schema, context, ids) => {
  // accepts an object { ids: [id1, id2] }
  if ((0, _lang.isObject)(ids) && !(0, _lang.isArray)(ids)) {
    ;
    var _ids = ids;
    ids = _ids.ids;
  }

  if ((0, _lang.isNumber)(ids)) {
    ids = ids.toString();
  }

  if ((0, _lang.isString)(ids)) {
    ids = [ids];
  } // accepts a s [id1, id2]


  if (!(0, _lang.isArray)(ids)) {
    throw new TypeError('refDocumentById expects ids to be an Object, a String, a Number or an Array');
  }

  var schemas = (0, _getSchemaLineage.default)(Schema);

  if (schemas.length < ids.length) {
    throw new Error("ids contains too many ids for the given Schema ".concat(Schema.name, " - ids: ").concat(ids));
  } else if (schemas.length > ids.length) {
    throw new Error("ids contains too few ids for the given Schema ".concat(Schema.name, " - ids: ").concat(ids));
  }

  return (0, _lang.reduce)((parentRef, [schema, id]) => {
    var ParentCollection = (0, _collection.default)(schema, _objectSpread(_objectSpread({}, context), {}, {
      parentRef
    }));
    return ParentCollection.doc(id.toString());
  }, context.parentRef, (0, _lang.zip)(schemas, ids));
});
var _default = refDocumentById;
exports.default = _default;
//# sourceMappingURL=refDocumentById.js.map