"use strict";

require("core-js/modules/es.array.concat");

require("core-js/modules/es.promise");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("regenerator-runtime/runtime");

var _path = require("../path");

var _identicalPathStats = _interopRequireDefault(require("./identicalPathStats"));

var _util = require("./util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

/**
 * recursively check if dest parent is a subdirectory of src.
 * It works for all file types including symlinks since it
 * checks the src and dest inodes. It starts from the deepest
 * parent and stops once it reaches the src parent or the root path.
 *
 * @function
 * @since v0.5.0
 * @category fs
 * @param {string} src The src path
 * @param {string} dest The dest path
 * @returns {undefined}
 */
var checkParentPaths = /*#__PURE__*/function () {
  var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee(src, srcStat, dest, funcName) {
    var srcParent, destParent, destStat;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            srcParent = (0, _path.pathResolve)((0, _path.pathDirname)(src));
            destParent = (0, _path.pathResolve)((0, _path.pathDirname)(dest));

            if (!(destParent === srcParent || destParent === (0, _path.pathParse)(destParent).root)) {
              _context.next = 4;
              break;
            }

            return _context.abrupt("return");

          case 4:
            _context.prev = 4;
            _context.next = 7;
            return (0, _util.stat)(destParent, {
              bigint: true
            });

          case 7:
            destStat = _context.sent;

            if (!(0, _identicalPathStats.default)(srcStat, destStat)) {
              _context.next = 10;
              break;
            }

            throw new Error("Cannot ".concat(funcName, " '").concat(src, "' to a subdirectory of itself, '").concat(dest, "'."));

          case 10:
            return _context.abrupt("return", checkParentPaths(src, srcStat, destParent, funcName));

          case 13:
            _context.prev = 13;
            _context.t0 = _context["catch"](4);

            if (!(_context.t0.code === 'ENOENT')) {
              _context.next = 17;
              break;
            }

            return _context.abrupt("return");

          case 17:
            throw _context.t0;

          case 18:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, null, [[4, 13]]);
  }));

  return function checkParentPaths(_x, _x2, _x3, _x4) {
    return _ref.apply(this, arguments);
  };
}();

var _default = checkParentPaths;
exports.default = _default;
//# sourceMappingURL=checkParentPaths.js.map