"use strict";

require("core-js/modules/es.array.concat");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _path = require("../path");

var _identicalPathStats = _interopRequireDefault(require("./identicalPathStats"));

var _util = require("./util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var bigIntStatSync = file => (0, _util.statSync)(file, {
  bigint: true
});

var getStatsSync = (src, dest) => {
  var destStat;
  var srcStat = bigIntStatSync(src);

  try {
    destStat = bigIntStatSync(dest);
  } catch (err) {
    if (err.code === 'ENOENT') {
      return {
        destStat: null,
        srcStat
      };
    }

    throw err;
  }

  return {
    destStat,
    srcStat
  };
};

var checkPathsSync = (src, dest, funcName) => {
  var _getStatsSync = getStatsSync(src, dest),
      destStat = _getStatsSync.destStat,
      srcStat = _getStatsSync.srcStat;

  if (destStat && (0, _identicalPathStats.default)(srcStat, destStat)) {
    throw new Error('Source and destination must not be the same.');
  }

  if (srcStat.isDirectory() && (0, _path.isPathSubdir)(src, dest)) {
    throw new Error("Cannot ".concat(funcName, " '").concat(src, "' to a subdirectory of itself, '").concat(dest, "'."));
  }

  return {
    destStat,
    srcStat
  };
};

var _default = checkPathsSync;
exports.default = _default;
//# sourceMappingURL=checkPathsSync.js.map