"use strict";

require("core-js/modules/es.array.filter");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _curry = _interopRequireDefault(require("./curry"));

var _isArray = _interopRequireDefault(require("./isArray"));

var _isFunction = _interopRequireDefault(require("./isFunction"));

var _isIterator = _interopRequireDefault(require("./isIterator"));

var _isObject = _interopRequireDefault(require("./isObject"));

var _iterate = _interopRequireDefault(require("./iterate"));

var _resolveWith = _interopRequireDefault(require("./resolveWith"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Resolves all async values in an array or object
 *
 * Auto curried for placeholder support.
 *
 * @function
 * @since v0.0.6
 * @category lang
 * @param {*} value The array or object whose values should be resolved. If value is not an object or array, the value is simply resolved to itself
 * @returns {*} The array or object with its values resolved
 * @example
 *
 * const nums = [
 *   1,
 *   Promise.resolve(2),
 *   (async () => 3)()
 * ]
 * await all(nums) //=> [ 1, 2, 3 ]
 *
 * const keyed = {
 *   a: 1,
 *   b: Promise.resolve(2),
 *   c: (async () => 3)()
 * }
 * await all(keyed) //=> { a: 1, b: 2, c: 3 }
 *
 * await all('abc') //=> 'abc'
 * await all(123) //=> 123
 */
var all = (0, _curry.default)((0, _resolveWith.default)(value => {
  // TODO BRN :When this method receives an empty Array or empty anything, it
  // will not return a Promise so anything attaching using .then will break
  var result;

  if ((0, _isArray.default)(value) || (0, _isIterator.default)(value)) {
    result = [];
  } else if ((0, _isObject.default)(value) && !(0, _isFunction.default)(value)) {
    result = {};
  } else {
    return value;
  }

  return (0, _iterate.default)(next => {
    if (next.done) {
      return _objectSpread(_objectSpread({}, next), {}, {
        value: result
      });
    }

    return (0, _resolveWith.default)(nextValue => {
      result[next.kdx] = nextValue;
      return next;
    }, next.value);
  }, value);
}));
var _default = all;
exports.default = _default;
//# sourceMappingURL=all.js.map