"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _allWith = _interopRequireDefault(require("./allWith"));

var _assocIndex = _interopRequireDefault(require("./assocIndex"));

var _assocKey = _interopRequireDefault(require("./assocKey"));

var _assocProperty = _interopRequireDefault(require("./assocProperty"));

var _curry = _interopRequireDefault(require("./curry"));

var _dispatchable = _interopRequireDefault(require("./dispatchable"));

var _satisfiesIndexed = _interopRequireDefault(require("./satisfiesIndexed"));

var _satisfiesKeyed = _interopRequireDefault(require("./satisfiesKeyed"));

var _satisfiesPropertied = _interopRequireDefault(require("./satisfiesPropertied"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var baseAssoc = (selector, value, collection) => {
  if ((0, _satisfiesIndexed.default)(collection)) {
    return (0, _assocIndex.default)(selector, value, collection);
  }

  if ((0, _satisfiesKeyed.default)(collection)) {
    return (0, _assocKey.default)(selector, value, collection);
  }

  if ((0, _satisfiesPropertied.default)(collection)) {
    return (0, _assocProperty.default)(selector, value, collection);
  }

  throw new Error("Cannot assoc to the given collection ".concat(collection));
};

var dispatchableAssoc = (0, _dispatchable.default)('assoc', baseAssoc);
/**
 * Makes a shallow clone of an object, setting or overriding the specified property with the given value. Note that this copies and flattens prototype properties onto the new object as well. All non-primitive properties are copied by reference.
 *
 * Supports path based property selectors 'foo.bar' and functional selectors which performs an over on the entire collection and sets each matching selector to the given value.
 *
 * @function
 * @since v0.3.0
 * @category lang
 * @param {Array | String | Function} selector The property path to set or functional selector
 * @param {Any} value The new value
 * @param {Any} collection The collection to clone and assign the new value
 * @returns {Any} A new collection equivalent to the original except for the changed selector path.
 * @example
 *
 * assoc('c', 3, {a: 1, b: 2})          //=> {a: 1, b: 2, c: 3}
 * assoc('c.d', 3, {a: 1, b: 2})        //=> {a: 1, b: 2, c: { d: 3 }}
 * assoc([ 'c', 'd' ], 3, {a: 1, b: 2}) //=> {a: 1, b: 2, c: { d: 3 }}
 */

var assoc = (0, _curry.default)((selector, value, collection) => (0, _allWith.default)(([resolvedSelector, resolvedCollection]) => dispatchableAssoc(resolvedSelector, value, resolvedCollection), [selector, collection]));
var _default = assoc;
exports.default = _default;
//# sourceMappingURL=assoc.js.map