"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _contagion = _interopRequireDefault(require("./contagion"));

var _get = _interopRequireDefault(require("./get"));

var _isFunction = _interopRequireDefault(require("./isFunction"));

var _isNil = _interopRequireDefault(require("./isNil"));

var _isString = _interopRequireDefault(require("./isString"));

var _util = require("./util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var cacheMethod = (options, method) => {
  var key = options.key,
      onHit = options.onHit,
      ttl = options.ttl;
  var keyFn;

  if ((0, _isString.default)(key)) {
    keyFn = () => key;
  } else if ((0, _isFunction.default)(key)) {
    keyFn = key;
  } else {
    throw new Error('cache key must be set to either a function or a string');
  }

  return (context, ...rest) => {
    var cache = context.cache,
        system = context.system;

    if (!cache) {
      throw new Error('Cache is missing from context. Likely it has not beeing included in your withContext enhancer.');
    }

    var cacheKey = keyFn(context, ...rest);
    var cached = (0, _get.default)(cacheKey, cache);

    if (cached && ((0, _isNil.default)(ttl) || ttl === Infinity || system.now() < cached.cachedAt + ttl)) {
      if ((0, _isFunction.default)(onHit)) {
        onHit(context, ...rest);
      }

      return cached.result;
    }

    var result = method(context, ...rest);
    (0, _util.anySetPathWith)(cache, (0, _util.anyToPath)(cacheKey), {
      cachedAt: system.now(),
      result
    }, _contagion.default, _get.default, _util.objectMutateSetProperty);
    return result;
  };
};

var _default = cacheMethod;
exports.default = _default;
//# sourceMappingURL=cacheMethod.js.map