"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/es.array.slice");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _flatten = _interopRequireDefault(require("./flatten"));

var _identity = _interopRequireDefault(require("./identity"));

var _reduceRight = _interopRequireDefault(require("./reduceRight"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Performs right-to-left function composition. The rightmost function may have any arity; the remaining functions must be unary.
 *
 * **Note:** The result of compose is not automatically curried.
 *
 * @function
 * @since v0.1.0
 * @category lang
 * @param {...Function} functions The functions to compose
 * @returns {Function}
 * @example
 *
 * const classyGreeting = (firstName, lastName) => "The name's " + lastName + ", " + firstName + " " + lastName
 * const yellGreeting = compose(toUpper, classyGreeting)
 * yellGreeting('James', 'Bond')
 * //=> "THE NAME'S BOND, JAMES BOND"
 *
 * compose(Math.abs, add(1), multiply(2))(-4) //=> 7
 */
var compose = (...functions) => {
  functions = (0, _flatten.default)(functions);
  var _functions = functions,
      length = _functions.length;

  if (length === 0) {
    return _identity.default;
  }

  if (length === 1) {
    return functions[0];
  }

  var lastFunc = functions[length - 1];
  var rest = functions.slice(0, length - 1);
  return (...args) => (0, _reduceRight.default)((composed, func) => func(composed), lastFunc(...args), rest);
};

var _default = compose;
exports.default = _default;
//# sourceMappingURL=compose.js.map