"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _assocMerge = _interopRequireDefault(require("./assocMerge"));

var _assocPath = _interopRequireDefault(require("./assocPath"));

var _createChannel = _interopRequireDefault(require("./createChannel"));

var _equals = _interopRequireDefault(require("./equals"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var createPropStore = channel => {
  if (!channel) {
    throw new Error('Channel is required');
  }

  var props = {};
  var first = true;
  var propChannel = (0, _createChannel.default)();

  var getProps = () => props;

  var put = action => {
    var nextProps;

    if (action.type === 'error') {
      nextProps = (0, _assocPath.default)(action.key, {
        error: action.error
      }, props);
    } else if (action.type === 'assoc') {
      nextProps = (0, _assocPath.default)(action.key, action.value, props);
    } else if (action.type === 'assocMerge') {
      nextProps = (0, _assocMerge.default)(action.value, props);
    } else if (action.type === 'set') {
      nextProps = action.value;
    } else {
      throw new Error("unsupported action type ".concat(action.type));
    }

    if (!(0, _equals.default)(nextProps, props) || first) {
      first = false;
      props = nextProps;
      propChannel.put(props);
      channel.put({
        type: 'refresh'
      });
    }
  };

  return {
    getProps,
    next: propChannel.next,
    put
  };
};

var _default = createPropStore;
exports.default = _default;
//# sourceMappingURL=createPropStore.js.map