"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _assoc = _interopRequireDefault(require("./assoc"));

var _createPath = _interopRequireDefault(require("./createPath"));

var _dissocProperty = _interopRequireDefault(require("./dissocProperty"));

var _first = _interopRequireDefault(require("./first"));

var _getProperty = _interopRequireDefault(require("./getProperty"));

var _isNil = _interopRequireDefault(require("./isNil"));

var _isString = _interopRequireDefault(require("./isString"));

var _size = _interopRequireDefault(require("./size"));

var _tail = _interopRequireDefault(require("./tail"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Makes a shallow clone of an object, removing the specified property. Note that this copies and flattens prototype properties onto the new object as well. All non-primitive properties are copied by reference.
 *
 * Supports path based property selectors 'foo.bar'.
 *
 * @function
 * @since v0.3.0
 * @category lang
 * @param {Array | String} selector The property path to delete
 * @param {Any} collection The collection to clone and remove the given property from
 * @returns {Any} A new collection equivalent to the original except for the property removed
 * @example
 *
 * dissocPath(['a'], {a: 1, b: 2})
 * //=> { b: 2 }
 *
 * dissocPath('c.d', {a: 1, b: 2, c: { d: 3 }})
 * //=> {a: 1, b: 2}
 *
 * dissocPath([ 'c', 'd' ],{a: 1, b: 2, c: { d: 3 }})
 * //=> {a: 1, b: 2}
 */
var dissocPath = (path, collection) => {
  if ((0, _isString.default)(path)) {
    path = (0, _createPath.default)(path);
  }

  if ((0, _size.default)(path) === 0) {
    return collection;
  }

  var part = (0, _first.default)(path);

  if ((0, _size.default)(path) === 1) {
    return (0, _dissocProperty.default)(part, collection);
  }

  var rest = (0, _tail.default)(path);
  var nextValue = (0, _getProperty.default)(part, collection);

  if ((0, _isNil.default)(nextValue)) {
    return collection;
  }

  return (0, _assoc.default)(part, dissocPath(rest, nextValue), collection);
};

var _default = dissocPath;
exports.default = _default;
//# sourceMappingURL=dissocPath.js.map