"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _defn = _interopRequireDefault(require("./defn"));

var _isPromise = _interopRequireDefault(require("./isPromise"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns the first element of the list which matches the predicate, or `undefined` if no element matches starting at the given index.
 *
 * Dispatches to the `findAtIndex` method of the last argument, if present.
 *
 * Supports async predicates. If a predicate returns a Promise than the entire method will upgrade to async and return a Promise.
 *
 * @function
 * @since v0.1.0
 * @category lang
 * @param {Function} fn The predicate function used to determine if the element is the
 *        desired one.
 * @param {Integer} index The index to start at.
 * @param {Array} list The array to consider.
 * @returns {*|Promise} The element found, or `undefined`.
 * @example
 *
 * const xs = [{a: 1}, {a: 2}, {a: 3}];
 * findAtIndex(propEq('a'), 0)(xs) //=> {a: 2}
 * findAtIndex(propEq('a', 2), 2)(xs) //=> undefined
 */
var findAtIndex = (0, _defn.default)('lang.findAtIndex', (fn, index, list) => {
  var length = list.length;
  var idx = index || 0; // TODO BRN: abstract this while loop pattern and make it reusable

  var _loop = function _loop() {
    var value = list[idx];
    var result = fn(list[idx], idx);

    if ((0, _isPromise.default)(result)) {
      return {
        v: result.then(resolvedResult => {
          if (resolvedResult) {
            return value;
          }

          return findAtIndex(fn, idx + 1, list);
        })
      };
    } else if (result) {
      return {
        v: value
      };
    }

    idx += 1;
  };

  while (idx < length) {
    var _ret = _loop();

    if (typeof _ret === "object") return _ret.v;
  }
});
var _default = findAtIndex;
exports.default = _default;
//# sourceMappingURL=findAtIndex.js.map