"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _defn = _interopRequireDefault(require("./defn"));

var _getPath = _interopRequireDefault(require("./getPath"));

var _isFunction = _interopRequireDefault(require("./isFunction"));

var _isPath = _interopRequireDefault(require("./isPath"));

var _isString = _interopRequireDefault(require("./isString"));

var _isUndefined = _interopRequireDefault(require("./isUndefined"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Retrieve the value at a given path.
 *
 * Paths can be defined by a string an array. The path parameter also accepts a function that will be used as a selector against the data.
 *
 *
 *
 * @function
 * @since v0.0.3
 * @category lang
 * @param {Array|string|number|Function} path The path to use.
 * @param {Object} value The value to retrieve the nested property from.
 * @returns {*} The data at `path`.
 * @example
 *
 * get(['a', 'b'], {a: {b: 2}})
 * //=> 2
 *
 * get(['a', 'b'], {c: {b: 2}})
 * //=> undefined
 *
 * get('a', {a: {b: 2}})
 * //=> { b: 2 }
 *
 * get('a.b', {a: {b: 2}})
 * //=> 2
 *
 * get('a[0]', {a: [ 1, 2 ]})
 * //=> 1
 *
 * get('[0]', [ 1, 2 ])
 * //=> 1
 */
var get = (0, _defn.default)('get', (selector, value) => {
  if ((0, _isUndefined.default)(selector)) {
    return value;
  }

  if ((0, _isFunction.default)(selector)) {
    return selector(value);
  }

  if (!(0, _isPath.default)(selector) && !(0, _isString.default)(selector)) {
    selector = [selector];
  }

  return (0, _getPath.default)(selector, value);
});
var _default = get;
exports.default = _default;
//# sourceMappingURL=get.js.map