"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _defn = _interopRequireDefault(require("./defn"));

var _getParentPath = _interopRequireDefault(require("./getParentPath"));

var _isArray = _interopRequireDefault(require("./isArray"));

var _isFunction = _interopRequireDefault(require("./isFunction"));

var _isUndefined = _interopRequireDefault(require("./isUndefined"));

var _toPath = _interopRequireDefault(require("./toPath"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Retrieve the parent value from a given path. The parent value is the value immediately before the last path part.
 *
 * Paths can be defined by a string an array. The path parameter also accepts a function that will be used as a selector against the data.
 *
 * @function
 * @since v0.3.0
 * @category lang
 * @param {Array|String|Number|Function} path The path to use.
 * @param {Object} value The value to retrieve the parent property value from.
 * @returns {Any} The data at `path`.
 * @example
 *
 * getParent(['a', 'b'], {a: {b: 2}})
 * //=> {b: 2}
 *
 * getParent(['a', 'b'], {c: {b: 2}})
 * //=> undefined
 *
 * getParent('a', {a: {b: 2}})
 * //=> {a: {b: 2}}
 *
 * getParent('a.b', {a: {b: 2}})
 * //=> {b: 2}
 *
 * getParent('a[0]', {a: [ 1, 2 ]})
 * //=> [ 1, 2 ]
 */
var getParent = (0, _defn.default)('getParent', (selector, value) => {
  if ((0, _isUndefined.default)(selector)) {
    return undefined; // has no parent since there's no path parts
  }

  if ((0, _isFunction.default)(selector)) {
    return selector(value);
  }

  var parts = selector;

  if (!(0, _isArray.default)(selector)) {
    parts = (0, _toPath.default)(selector, value);
  }

  return (0, _getParentPath.default)(parts, value);
});
var _default = getParent;
exports.default = _default;
//# sourceMappingURL=getParent.js.map