"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _createPath = _interopRequireDefault(require("./createPath"));

var _curry = _interopRequireDefault(require("./curry"));

var _getProperty = _interopRequireDefault(require("./getProperty"));

var _isPath = _interopRequireDefault(require("./isPath"));

var _isString = _interopRequireDefault(require("./isString"));

var _isUndefined = _interopRequireDefault(require("./isUndefined"));

var _size = _interopRequireDefault(require("./size"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Retrieve the value at a given selector
 *
 * @function
 * @since v0.4.3
 * @category lang
 * @param {Array|ImmutableList|String} path The path to use.
 * @param {Object} object The object to get the path in.
 * @return {Any} The value that exists at the path or undefined.
 * @example
 *
 * get(['a', 'b'], { a: { b: 2 } })
 * // => 2
 *
 * get(['a', 'b'], { c: { b: 2 } })
 * // => undefined
 *
 * get('a', { a: { b: 2 } })
 * // => { b: 2 }
 *
 * get('a.b', { a: { b: 2 } })
 * // => 2
 *
 * get('a[0]', { a: [1, 2] })
 * // => 1
 *
 * get('[0]', [1, 2])
 * // => 1
 */
var getPath = (0, _curry.default)((path, obj) => {
  if ((0, _isString.default)(path)) {
    path = (0, _createPath.default)(path);
  }

  if (!(0, _isPath.default)(path)) {
    throw new TypeError("getPath expected 'path' parameter to be a Path. Instead received ".concat(path));
  }

  var val = obj;
  var idx = 0;
  var length = (0, _size.default)(path);

  while (idx < length) {
    val = (0, _getProperty.default)((0, _getProperty.default)(idx, path), val);

    if ((0, _isUndefined.default)(val)) {
      return val;
    }

    idx += 1;
  }

  return val;
});
var _default = getPath;
exports.default = _default;
//# sourceMappingURL=getPath.js.map