"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _createPath = _interopRequireDefault(require("./createPath"));

var _curry = _interopRequireDefault(require("./curry"));

var _getProperty = _interopRequireDefault(require("./getProperty"));

var _hasProperty = _interopRequireDefault(require("./hasProperty"));

var _isNil = _interopRequireDefault(require("./isNil"));

var _isPath = _interopRequireDefault(require("./isPath"));

var _isString = _interopRequireDefault(require("./isString"));

var _isSymbol = _interopRequireDefault(require("./isSymbol"));

var _size = _interopRequireDefault(require("./size"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns whether or not a path exists in an object. Only the object's
 * own properties are checked.
 *
 * @function
 * @since v0.4.3
 * @category lang
 * @param {Array|ImmutableList|String} path The path to use.
 * @param {Object} object The object to check the path in.
 * @return {Boolean} Whether the path exists.
 * @example
 *
 *      hasPath(['a', 'b'], {a: {b: 2}})         // => true
 *      hasPath(['a', 'b'], {a: {b: undefined}}) // => true
 *      hasPath(['a', 'b'], {a: {c: 2}})         // => false
 *      hasPath(['a', 'b'], {})                  // => false
 */
var hasPath = (0, _curry.default)((path, obj) => {
  if ((0, _isString.default)(path) || (0, _isSymbol.default)(path)) {
    path = (0, _createPath.default)(path);
  }

  if (!(0, _isPath.default)(path)) {
    throw new TypeError("getPath expected 'path' parameter to be a Path. Instead received ".concat(path));
  }

  if (path.length === 0 || (0, _isNil.default)(obj)) {
    return false;
  }

  var val = obj;
  var idx = 0;
  var length = (0, _size.default)(path);

  while (idx < length) {
    if (!(0, _isNil.default)(val) && (0, _hasProperty.default)((0, _getProperty.default)(idx, path), val)) {
      val = (0, _getProperty.default)((0, _getProperty.default)(idx, path), val);
      idx += 1;
    } else {
      return false;
    }
  }

  return true;
});
var _default = hasPath;
exports.default = _default;
//# sourceMappingURL=hasPath.js.map