"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _curry = _interopRequireDefault(require("./curry"));

var _getProperty = _interopRequireDefault(require("./getProperty"));

var _isString = _interopRequireDefault(require("./isString"));

var _size = _interopRequireDefault(require("./size"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns the nth element of the given list or string. If n is negative the
 * element at index length + n is returned.
 *
 * @function
 * @since v0.1.0
 * @category lang
 * @param {Number} offset The offset from the 0 index to select from. If negative it will be subtracted from length
 * @param {Indexed} collection The collection to select from
 * @returns {Any} The value at the nth index
 * @example
 *
 * const list = ['foo', 'bar', 'baz', 'quux']
 * nth(1, list) //=> 'bar'
 * nth(-1, list) //=> 'quux'
 * nth(-99, list) //=> undefined
 *
 * nth(2, 'abc') //=> 'c'
 * nth(3, 'abc') //=> ''
 */
var nth = (0, _curry.default)((offset, list) => {
  var idx = offset < 0 ? (0, _size.default)(list) + offset : offset;
  return (0, _isString.default)(list) ? list.charAt(idx) : (0, _getProperty.default)(idx, list);
});
var _default = nth;
exports.default = _default;
//# sourceMappingURL=nth.js.map