"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _allWith = _interopRequireDefault(require("./allWith"));

var _assocPath = _interopRequireDefault(require("./assocPath"));

var _curry = _interopRequireDefault(require("./curry"));

var _isPath = _interopRequireDefault(require("./isPath"));

var _isString = _interopRequireDefault(require("./isString"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * This method is an alias for `assoc`
 *
 * Makes a shallow clone of an object, setting or overriding the specified property with the given value. Note that this copies and flattens prototype properties onto the new object as well. All non-primitive properties are copied by reference.
 *
 * Supports path based property selectors 'foo.bar' and functional selectors which performs an 'over' on the entire collection and sets each matching selector to the given value.
 *
 * dispatches to the `set` method of the 3rd argument if available
 *
 * @function
 * @since v0.3.0
 * @category lang
 * @param {Array | String | Function} selector The property path to set or functional selector
 * @param {Any} value The new value
 * @param {Any} collection The collection to clone and assign the new value
 * @returns {Any} A new collection equivalent to the original except for the changed selector path.
 * @example
 *
 * set('c', 3, {a: 1, b: 2})          //=> {a: 1, b: 2, c: 3}
 * set('c.d', 3, {a: 1, b: 2})        //=> {a: 1, b: 2, c: { d: 3 }}
 * set([ 'c', 'd' ], 3, {a: 1, b: 2}) //=> {a: 1, b: 2, c: { d: 3 }}
 */
// NOTE BRN: We use curry here instead of defn because there are data
// implementations where we don't want to directly dispatch to .set. The Sutter
// implementation will fix this once we can switch to that
var set = (0, _curry.default)((selector, value, collection) => (0, _allWith.default)(([resolvedSelector, resolvedCollection]) => {
  if (!(0, _isPath.default)(resolvedSelector) && !(0, _isString.default)(resolvedSelector)) {
    resolvedSelector = [resolvedSelector];
  }

  return (0, _assocPath.default)(resolvedSelector, value, resolvedCollection);
}, [selector, collection]));
var _default = set;
exports.default = _default;
//# sourceMappingURL=set.js.map