"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _curry = _interopRequireDefault(require("./curry"));

var _getProperty = _interopRequireDefault(require("./getProperty"));

var _hasProperty = _interopRequireDefault(require("./hasProperty"));

var _identical = _interopRequireDefault(require("./identical"));

var _keys = _interopRequireDefault(require("./keys"));

var _size = _interopRequireDefault(require("./size"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Performs equality by iterating through keys on an object and returning false when any key has values which are not strictly equal between the arguments. Returns true when the values of all keys are strictly equal.
 *
 * @function
 * @since v0.1.0
 * @category lang
 * @param {Array | String | Function} selector The property path to set or functional selector
 * @param {object} objA The object to compare to B
 * @param {object} objB The object to compare to A
 * @returns {boolean} Whether or not the two objects are shallowly equal
 * @example
 *
 * shallowEquals({ a: 1, b: 2, c: undefined }, { a: 1, b: 2, c: undefined }) //=> true
 * shallowEquals({ a: 1, b: 2, c: 3 }, { a: 1, b: 2 }) //=> false
 */
var shallowEquals = (0, _curry.default)((objA, objB) => {
  if ((0, _identical.default)(objA, objB)) {
    return true;
  }

  if (typeof objA !== 'object' || objA === null || typeof objB !== 'object' || objB === null) {
    return false;
  }

  var keysA = (0, _keys.default)(objA);
  var keysB = (0, _keys.default)(objB);

  if ((0, _size.default)(keysA) !== (0, _size.default)(keysB)) {
    return false;
  } // Test for A's keys different from B.


  for (var i = 0; i < keysA.length; i++) {
    if (!(0, _hasProperty.default)((0, _getProperty.default)(i, keysA), objB) || !(0, _identical.default)((0, _getProperty.default)((0, _getProperty.default)(i, keysA), objA), (0, _getProperty.default)((0, _getProperty.default)(i, keysA), objB))) {
      return false;
    }
  }

  return true;
});
var _default = shallowEquals;
exports.default = _default;
//# sourceMappingURL=shallowEquals.js.map