"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsLength = _interopRequireDefault(require("./anyIsLength"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is array-like. A value is considered array-like if it's not a function and has a `value.length` that's an integer greater than or equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
 * @example
 *
 * anyIsArrayLike([1, 2, 3])
 * // => true
 *
 * anyIsArrayLike(document.body.children)
 * // => true
 *
 * anyIsArrayLike('abc')
 * // => true
 *
 * anyIsArrayLike(Function)
 * // => false
 */
var anyIsArrayLike = value => value != null && typeof value != 'function' && (0, _anyIsLength.default)(value.length);

var _default = anyIsArrayLike;
exports.default = _default;
//# sourceMappingURL=anyIsArrayLike.js.map