"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsObjectLike = _interopRequireDefault(require("./anyIsObjectLike"));

var _anyIsPlainObject = _interopRequireDefault(require("./anyIsPlainObject"));

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is an `Error`, `EvalError`, `RangeError`, `ReferenceError`, `SyntaxError`, `TypeError`, or `URIError` object.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `any` is an `Error` object, else `false`.
 * @example
 *
 * anyIsError(new Error)
 * // => true
 *
 * anyIsError(Error)
 * // => false
 */
var anyIsError = any => {
  if (!(0, _anyIsObjectLike.default)(any)) {
    return false;
  }

  var tag = (0, _anyToStringTag.default)(any);
  return tag == 'Error' || tag == 'DOMException' || typeof any.message == 'string' && typeof any.name == 'string' && !(0, _anyIsPlainObject.default)(any);
};

var _default = anyIsError;
exports.default = _default;
//# sourceMappingURL=anyIsError.js.map