"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsObject = _interopRequireDefault(require("./anyIsObject"));

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is classified as a `Function` object.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `value` is a function, else `false`.
 * @example
 *
 * anyIsFunction(function() {})
 * // => true
 *
 * anyIsFunction(/abc/)
 * // => false
 */
var anyIsFunction = any => {
  if (!(0, _anyIsObject.default)(any)) {
    return false;
  } // The use of `Object#toString` avoids issues with the `typeof` operator
  // in Safari 9 which returns 'object' for typed arrays and other constructors.


  var tag = (0, _anyToStringTag.default)(any);
  return tag == 'Function' || tag == 'AsyncFunction' || tag == 'GeneratorFunction' || tag == 'Proxy';
};

var _default = anyIsFunction;
exports.default = _default;
//# sourceMappingURL=anyIsFunction.js.map