"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

var _functionToString = _interopRequireDefault(require("./functionToString"));

var _objectGetPrototypeOf = _interopRequireDefault(require("./objectGetPrototypeOf"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isFnRegex = /^\s*(?:function)?\*/;

var getGeneratorFunc = () => {
  try {
    return Function('return function*() {}')();
  } catch (e) {}
};

var generatorFunc = getGeneratorFunc();
var GeneratorFunction = generatorFunc ? (0, _objectGetPrototypeOf.default)(generatorFunc) : {};
/**
 * Checks whether a function is generator function.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param  {*} any The any to check.
 * @returns {boolean} Returns `true` if `any` is a generator function, else `false`.
 * @example
 *
 * anyIsGeneratorFunction(function*() {})
 * //=> true
 *
 * anyIsGeneratorFunction(function() {})
 * //=> false
 */

var anyIsGeneratorFunction = any => {
  if (typeof any !== 'function') {
    return false;
  }

  if (isFnRegex.test((0, _functionToString.default)(any))) {
    return true;
  }

  if ((0, _anyToStringTag.default)(any) === 'GeneratorFunction') {
    return true;
  }

  return (0, _objectGetPrototypeOf.default)(any) === GeneratorFunction;
};

var _default = anyIsGeneratorFunction;
exports.default = _default;
//# sourceMappingURL=anyIsGeneratorFunction.js.map