"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _classes = require("../classes");

var _Integer = require("../constants/Integer");

var _Regex = require("../constants/Regex");

/**
 * Checks if `value` is a valid array-like index.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
 * @example
 *
 * anyIsIndex(0)
 * //=> true
 *
 * anyIsIndex(1)
 * //=> true
 *
 * anyIsIndex(-1)
 * //=> false
 */
var anyIsIndex = any => {
  if (any instanceof _classes.Index) {
    return true;
  } // NOTE BRN: max safe length is exactly MAX_SAFE since the length of an array cannot safely be greater than the max integer.


  var type = typeof any;
  return (type === 'number' || type != 'symbol' && _Regex.UINT.test(any)) && any > -1 && any % 1 == 0 && any < _Integer.MAX_SAFE;
};

var _default = anyIsIndex;
exports.default = _default;
//# sourceMappingURL=anyIsIndex.js.map