"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

var _anyIsIterator = _interopRequireDefault(require("./anyIsIterator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is an IndexedIterator. An IndexedIterator is classified as having a property named `next` that is a plain function and a property named `getIndex` that is a plain function.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `value` is an IndexedIterator
 * @example
 *
 * anyIsIndexedIterator({
 *   next: () => {}
 * })
 * //=> true
 *
 * const array = []
 * anyIsIndexedIterator(array[Symbol.iterator])
 * //=> false
 */
var anyIsIndexedIterator = any => (0, _anyIsIterator.default)(any) && (0, _anyIsFunction.default)(any.getIndex);

var _default = anyIsIndexedIterator;
exports.default = _default;
//# sourceMappingURL=anyIsIndexedIterator.js.map