"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Infinity = _interopRequireDefault(require("../classes/Infinity"));

var _anyIsNumber = _interopRequireDefault(require("./anyIsNumber"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is `Infinity` or `-Infinity`.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `any` is `Infinity` or `-Infinity`, else `false`.
 * @example
 *
 * anyIsInfinity(Infinity)
 * // => true
 *
 * anyIsInfinity(-Infinity)
 * // => true
 *
 * anyIsInfinity(new Number(Infinity))
 * // => true
 *
 * anyIsInfinity(undefined)
 * // => false
 *
 * anyIsInfinity(123)
 * // => false
 */
var anyIsInfinity = value => (0, _anyIsNumber.default)(value) && (_Infinity.default === +value || -_Infinity.default === +value);

var _default = anyIsInfinity;
exports.default = _default;
//# sourceMappingURL=anyIsInfinity.js.map