"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsNumber = _interopRequireDefault(require("./anyIsNumber"));

var _anyToInteger = _interopRequireDefault(require("./anyToInteger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Determine if the given value is an integer.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} value The value to check.
 * @returns {Boolean} Returns `true` if `any` is an integer, else `false`.
 * @example
 *
 * anyIsInteger(3)
 * // => true
 *
 * anyIsInteger(new Number(3))
 * // => true
 *
 * anyIsInteger(3.2)
 * // => false

 * anyIsInteger(Number.MIN_VALUE)
 * // => false
 *
 * anyIsInteger(Infinity)
 * // => false
 *
 * anyIsInteger(NaN)
 * // => false
 *
 * anyIsInteger('3')
 * // => false
 */
var anyIsInteger = value => (0, _anyIsNumber.default)(value) && value == (0, _anyToInteger.default)(value);

var _default = anyIsInteger;
exports.default = _default;
//# sourceMappingURL=anyIsInteger.js.map