"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is an `Iterator`. An `Iterator` is classified as having a property named `next` that is a function.
 *
 * Note, this method returns `true` for async Iterators.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is an Iterator
 * @example
 *
 * const array = []
 * anyIsIterator(array[Symbol.iterator])
 * //=> true
 *:
 * anyIsIterator({
 *   next: () => {}
 * })
 * //=> true
 */
var anyIsIterator = value => value != null && (0, _anyIsFunction.default)(value.next);

var _default = anyIsIterator;
exports.default = _default;
//# sourceMappingURL=anyIsIterator.js.map