"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

var _anyIsIterator = _interopRequireDefault(require("./anyIsIterator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is a KeyedIterator. A KeyedIterator is classified as having a
 * property named `next` that is a plain function and a property named `getKey`
 * that returns the current key.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Any} any The value to check.
 * @returns {Boolean} Returns `true` if `value` is a KeyedIterator
 * @example
 *
 * const object = {}
 * anyIsKeyedIterator(objectToIterator(object))
 * //=> true
 *
 * const array = []
 * anyIsKeyedIterator(arrayLikeToIterator(array))
 * //=> false
 *
 * anyIsKeyedIterator({
 *   next: () => {},
 *   getKey: () => {}
 * })
 * //=> true
 */
var anyIsKeyedIterator = any => (0, _anyIsIterator.default)(any) && (0, _anyIsFunction.default)(any.getKey);

var _default = anyIsKeyedIterator;
exports.default = _default;
//# sourceMappingURL=anyIsKeyedIterator.js.map