"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsObjectLike = _interopRequireDefault(require("./anyIsObjectLike"));

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `value` is classified as a `Number` primitive or object.
 *
 * **Note:** To exclude `Infinity`, `-Infinity`, and `NaN`, which are
 * classified as numbers, use the `Number.isFinite` method.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is a number, else `false`.
 * @example
 *
 * anyIsNumber(3)
 * // => true
 *
 * anyIsNumber(Number.MIN_VALUE)
 * // => true
 *
 * anyIsNumber(Infinity)
 * // => true
 *
 * anyIsNumber('3')
 * // => false
 */
var anyIsNumber = value => typeof value == 'number' || (0, _anyIsObjectLike.default)(value) && (0, _anyToStringTag.default)(value) == 'Number';

var _default = anyIsNumber;
exports.default = _default;
//# sourceMappingURL=anyIsNumber.js.map