"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks whether the given value is an Observer.
 *
 * @private
 * @function
 * @since v0.2.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `value` is an `Observer`, else `false`.
 * @example
 *
 * anyIsObserver({
 *   next: () => {},
 *   error: () => {},
 *   complete: () => {}
 * }))
 * //=> true
 *
 * anyIsObserver({})
 * //=> false
 */
var anyIsObserver = any => any != null && (0, _anyIsFunction.default)(any.next) && (0, _anyIsFunction.default)(any.error) && (0, _anyIsFunction.default)(any.complete);

var _default = anyIsObserver;
exports.default = _default;
//# sourceMappingURL=anyIsObserver.js.map