"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Path = _interopRequireDefault(require("../classes/Path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is a Path.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Any} any The value to check.
 * @returns {Boolean} Returns `true` if `any` is a property name, else `false`.
 * @example
 *
 * anyIsPath([])
 * //=> true
 *
 * anyIsPath(['foo'])
 * //=> true
 *
 * anyIsPath(['foo', 'bar'])
 * //=> true
 *
 * anyIsPath([Symbol('abc')])
 * //=> true
 *
 * anyIsPath([123, undefined, null])
 * //=> true
 *
 * anyIsPath([ {}, [], new Map()])
 * //=> true
 *
 * anyIsPath(new String('foo'))
 * //=> false
 *
 * anyIsPath(123)
 * //=> false
 *
 * anyIsPath(true)
 * //=> false
 *
 * anyIsPath(null)
 * //=> false
 *
 * anyIsPath(undefined)
 * //=> false
 *
 * anyIsPath({})
 * //=> false
 */
var anyIsPath = any => any instanceof _Path.default;

var _default = anyIsPath;
exports.default = _default;
//# sourceMappingURL=anyIsPath.js.map