"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsObject = _interopRequireDefault(require("./anyIsObject"));

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is plain function. A plain function is not an AsyncFunction and not a GeneratorFunction
 *
 * @private
 * @function
 * @since v0.3.0
 * @category lang.util
 * @param {Any} any The value to check.
 * @returns {Boolean} Returns `true` if `any` is a plain function, else `false`.
 * @example
 *
 * anyIsPlainFunction(() => {})
 * // => true
 *
 * anyIsPlainFunction(function() {})
 * // => true
 *
 * anyIsPlainFunction(async function() {})
 * // => false
 *
 * anyIsPlainFunction(function* () {})
 * // => false
 */
var anyIsPlainFunction = any => {
  if (!(0, _anyIsObject.default)(any)) {
    return false;
  }

  var tag = (0, _anyToStringTag.default)(any);
  return tag == 'Function' || tag == 'Proxy';
};

var _default = anyIsPlainFunction;
exports.default = _default;
//# sourceMappingURL=anyIsPlainFunction.js.map