"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsObjectLike = _interopRequireDefault(require("./anyIsObjectLike"));

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

var _objectGetPrototypeOf = _interopRequireDefault(require("./objectGetPrototypeOf"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `value` is a plain object, that is, an object created by the
 * `Object` constructor or one with a `[[Prototype]]` of `null`.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `value` is a plain object, else `false`.
 * @example
 *
 * function Foo() {
 *   this.a = 1
 * }
 *
 * anyIsPlainObject(new Foo)
 * //=> false
 *
 * anyIsPlainObject([1, 2, 3])
 * //=> false
 *
 * anyIsPlainObject({ 'x': 0, 'y': 0 })
 * //=> true
 *
 * anyIsPlainObject(Object.create(null))
 * //=> true
 */
var anyIsPlainObject = any => {
  if (!(0, _anyIsObjectLike.default)(any) || (0, _anyToStringTag.default)(any) != 'Object') {
    return false;
  }

  if ((0, _objectGetPrototypeOf.default)(any) === null) {
    return true;
  }

  var proto = any;

  while ((0, _objectGetPrototypeOf.default)(proto) !== null) {
    proto = (0, _objectGetPrototypeOf.default)(proto);
  }

  return (0, _objectGetPrototypeOf.default)(any) === proto;
};

var _default = anyIsPlainObject;
exports.default = _default;
//# sourceMappingURL=anyIsPlainObject.js.map