"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _classes = require("../classes");

var _anyIsString = _interopRequireDefault(require("./anyIsString"));

var _anyIsSymbol = _interopRequireDefault(require("./anyIsSymbol"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is a Property
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `any` is a Property, else `false`.
 * @example
 *
 * anyIsProperty('foo')
 * //=> true
 *
 * anyIsProperty('foo.bar')
 * //=> true
 *
 * anyIsProperty(Symbol('abc'))
 * //=> true
 *
 * anyIsProperty(Symbol.for('foo'))
 * //=> true
 *
 * anyIsProperty(new String('foo'))
 * //=> true
 *
 * anyIsProperty(123)
 * //=> false
 *
 * anyIsProperty(true)
 * //=> false
 *
 * anyIsProperty(null)
 * //=> false
 *
 * anyIsProperty(undefined)
 * //=> false
 *
 * anyIsProperty([])
 * //=> false
 *
 * anyIsProperty({})
 * //=> false
 */
var anyIsProperty = any => (0, _anyIsSymbol.default)(any) || (0, _anyIsString.default)(any) || any instanceof _classes.Property;

var _default = anyIsProperty;
exports.default = _default;
//# sourceMappingURL=anyIsProperty.js.map