"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

var _anyIsGenerator = _interopRequireDefault(require("./anyIsGenerator"));

var _anyIsObject = _interopRequireDefault(require("./anyIsObject"));

var _anyIsOp = _interopRequireDefault(require("./anyIsOp"));

var _anyIsPromise = _interopRequireDefault(require("./anyIsPromise"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Determines if `any` is a resolvable value.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any
 * @returns {boolean}
 * @example
 *
 * anyIsResolved({
 *   ['@@redux-saga/IO']: 'op'
 * })
 * //=> false
 *
 * anyIsResolved((function* () {})())
 * //=> false
 *
 * anyIsResolved(new Promise(() => {})))
 * //=> false
 *
 * anyIsResolved({ resolve: () => 'foo' })
 * //=> false
 *
 * anyIsResolved(null)
 * //=> true
 *
 * anyIsResolved(undefined)
 * //=> true
 *
 * anyIsResolved('abc')
 * //=> true
 */
var anyIsResolved = any => !(0, _anyIsObject.default)(any) || !((0, _anyIsPromise.default)(any) || (0, _anyIsFunction.default)(any.resolve) || (0, _anyIsGenerator.default)(any) || (0, _anyIsOp.default)(any));

var _default = anyIsResolved;
exports.default = _default;
//# sourceMappingURL=anyIsResolved.js.map