"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsArray = _interopRequireDefault(require("./anyIsArray"));

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is classified as a `String` primitive or object.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `any` is a string, else `false`.
 * @example
 *
 * anyIsString('abc')
 * // => true
 *
 * anyIsString(new String('abc'))
 * // => true
 *
 * anyIsString(1)
 * // => false
 */
var anyIsString = any => {
  var type = typeof any;
  return type == 'string' || type == 'object' && any != null && !(0, _anyIsArray.default)(any) && (0, _anyToStringTag.default)(any) == 'String';
};

var _default = anyIsString;
exports.default = _default;
//# sourceMappingURL=anyIsString.js.map