"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if `any` is classified as a `Symbol` primitive or object.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to check.
 * @returns {boolean} Returns `true` if `any` is a symbol, else `false`.
 * @example
 *
 * anyIsSymbol(Symbol.iterator)
 * // => true
 *
 * anyIsSymbol(Symbol('abc'))
 * // => true
 *
 * anyIsSymbol(Symbol.for('abc'))
 * // => true
 *
 * anyIsSymbol('abc')
 * // => false
 */
var anyIsSymbol = any => {
  var type = typeof any;
  return type == 'symbol' || type == 'object' && any != null && (0, _anyToStringTag.default)(any) == 'Symbol';
};

var _default = anyIsSymbol;
exports.default = _default;
//# sourceMappingURL=anyIsSymbol.js.map