"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Iterator = require("../constants/Iterator");

var _anyIsResolved = _interopRequireDefault(require("./anyIsResolved"));

var _anyToIterator = _interopRequireDefault(require("./anyToIterator"));

var _unresolvedResolveWith = _interopRequireDefault(require("./unresolvedResolveWith"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var resolveNext = (next, fn, iter, recur) => (0, _unresolvedResolveWith.default)(next, resolvedNext => {
  if (resolvedNext.done) {
    return resolvedNext.value;
  }

  return recur(fn, iter);
});

var doReverseSeriesIteration = (fn, iter) => {
  var _loop = function _loop() {
    var next = iter.previous();

    if (!(0, _anyIsResolved.default)(next)) {
      return {
        v: (0, _unresolvedResolveWith.default)(next, resolvedNext => {
          next = fn(resolvedNext);

          if (!(0, _anyIsResolved.default)(next)) {
            return resolveNext(next, fn, iter, doReverseSeriesIteration);
          }

          if (next.done) {
            return next.value;
          }

          return doReverseSeriesIteration(fn, iter);
        })
      };
    }

    next = fn(next);

    if (!(0, _anyIsResolved.default)(next)) {
      return {
        v: resolveNext(next, fn, iter, doReverseSeriesIteration)
      };
    }

    if (next.done) {
      return {
        v: next.value
      };
    }
  };

  while (true) {
    var _ret = _loop();

    if (typeof _ret === "object") return _ret.v;
  }
};
/**
 * This method iterates over the given collection or iterator in **series**. If the `iteratee` method returns `{ done: true }` then the iteration will complete.
 *
 * This method automatically upgrades to async. If the `iteratee` returns a Promise or a generator, this method will return a Promise or a generator. Values are iterated in order and if the iteratee returns a resolvable value the iteration will wait until that value resolves before continuing with the iteration.
 *
 * This method also supports async iterators. If an unresolved value is received from the iterator instead of an object with `value` and `done` properties, the iteration will wait for the value to resolve before continuing to the next iteration. This will also cause the method to upgrade to async and return a Promise.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Function} iteratee The iteratee Function
 * @param  {*} collection The collection or iterator to iterate over
 * @returns {*} The final value returned when the iteratee returns done or `undefined`
 * @example
 *
 * anyIterateRight((value, kdx) => {
 *   if (value === 'b') {
 *     return { done: true, value: kdx }
 *   }
 *   return { done: false }
 * }, ['a', 'b', 'c'])
 * //=> 1
 *
 * anyIterateRight(async (value, kdx) => new Promise((resolve, reject) => {
 *   setTimeout(() => {
 *     if (value === 'b') {
 *       return resolve({ done: true, value: kdx })
 *     }
 *     return resolve({ done: false })
 *   }, 0)
 * }), ['a', 'b', 'c'])
 * //=> 1
 */


var anyIterateRight = (any, func) => doReverseSeriesIteration(func, (0, _anyToIterator.default)(any, _Iterator.END));

var _default = anyIterateRight;
exports.default = _default;
//# sourceMappingURL=anyIterateRight.js.map