"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

var _anyIsPromise = _interopRequireDefault(require("./anyIsPromise"));

var _anyIsResolved = _interopRequireDefault(require("./anyIsResolved"));

var _anyResolveToGenerator = _interopRequireDefault(require("./anyResolveToGenerator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Resolves a value.
 *
 * If the value is a `Promise`, this will return a Promise that will then resolve
 * the returned value.
 *
 * Dispatches to the `resolve` method if it exists. If a resolve method returns
 * a value that is also resolvable, this method will resolve that value as
 * well.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to resolve.
 * @returns {*} The resolved value.
 * @example
 *
 * anyResolve('foo')
 * // => 'foo'
 *
 * anyResolve({
 *  resolve: () => 'bar'
 * })
 * //=> bar
 *
 * anyResolve({
 *   resolve: () => ({
 *     resolve: () => 'bar'
 *   })
 * })
 * //=> bar
 */
var anyResolve = any => {
  if (!(0, _anyIsResolved.default)(any)) {
    if ((0, _anyIsFunction.default)(any.resolve)) {
      return anyResolve(any.resolve());
    }

    if ((0, _anyIsPromise.default)(any)) {
      return any.then(resolved => anyResolve(resolved));
    }

    return (0, _anyResolveToGenerator.default)(any);
  }

  return any;
};

var _default = anyResolve;
exports.default = _default;
//# sourceMappingURL=anyResolve.js.map