"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("regenerator-runtime/runtime");

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

var _anyIsGenerator = _interopRequireDefault(require("./anyIsGenerator"));

var _anyIsResolved = _interopRequireDefault(require("./anyIsResolved"));

var _unresolvedResolveToGenerator = _interopRequireDefault(require("./unresolvedResolveToGenerator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Resolves a value to a generator using the generator to yield values. When the
 * generator is complete the fn method is executed with the final result.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to resolve with the generator
 * @param {Function} func The function to execute at the end of the generator's resolution
 * @returns {Generator}
 * @example
 *
 * const generator = anyResolveToGeneratorWith(
 *   (resolvedValue) => {
 *     //=> 'foo'
 *   },
 *   'foo'
 * )
 * generator.next()
 * //=> { done: true } triggers the fn method
 */
var anyResolveToGeneratorWith = /*#__PURE__*/regeneratorRuntime.mark(function anyResolveToGeneratorWith(any, func) {
  var result;
  return regeneratorRuntime.wrap(function anyResolveToGeneratorWith$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          if ((0, _anyIsResolved.default)(any)) {
            _context.next = 15;
            break;
          }

          if (!(0, _anyIsGenerator.default)(any)) {
            _context.next = 6;
            break;
          }

          return _context.delegateYield(any, "t0", 3);

        case 3:
          result = _context.t0;
          _context.next = 13;
          break;

        case 6:
          if (!(0, _anyIsFunction.default)(any.resolve)) {
            _context.next = 10;
            break;
          }

          result = any.resolve();
          _context.next = 13;
          break;

        case 10:
          _context.next = 12;
          return any;

        case 12:
          result = _context.sent;

        case 13:
          return _context.delegateYield(anyResolveToGeneratorWith(result, func), "t1", 14);

        case 14:
          return _context.abrupt("return", _context.t1);

        case 15:
          any = func(any);

          if ((0, _anyIsResolved.default)(any)) {
            _context.next = 19;
            break;
          }

          return _context.delegateYield((0, _unresolvedResolveToGenerator.default)(any), "t2", 18);

        case 18:
          return _context.abrupt("return", _context.t2);

        case 19:
          return _context.abrupt("return", any);

        case 20:
        case "end":
          return _context.stop();
      }
    }
  }, anyResolveToGeneratorWith);
});
var _default = anyResolveToGeneratorWith;
exports.default = _default;
//# sourceMappingURL=anyResolveToGeneratorWith.js.map