"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsGenerator = _interopRequireDefault(require("./anyIsGenerator"));

var _anyIsOp = _interopRequireDefault(require("./anyIsOp"));

var _anyIsPromise = _interopRequireDefault(require("./anyIsPromise"));

var _anyIsResolved = _interopRequireDefault(require("./anyIsResolved"));

var _anyResolve = _interopRequireDefault(require("./anyResolve"));

var _anyResolveToGeneratorWith = _interopRequireDefault(require("./anyResolveToGeneratorWith"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Resolves a value to the given method.
 *
 * If the value to be resolved is a promise then this method will return a promise. The fn method will be triggered once the promise resolves.
 *
 * If the value to be resolved is a generator, this method will return a generator.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Any} any The value to resolve with the generator
 * @param {Function} func The function to execute at the end of the resolution
 * @returns {Generator|Promise|Any}
 * @example
 *
 * await anyResolveWith(
 *   Promise.resolve('foo'),
 *   (resolvedValue) => 'bar' // resolvedValue == 'foo'
 * )
 * //=> 'bar'
 *
 * anyResolveWith(
 *   'foo',
 *   (resolvedValue) => 'bar' // resolvedValue == 'foo'
 * )
 * //=> 'bar'
 */
var anyResolveWith = (any, func) => {
  if (!(0, _anyIsResolved.default)(any)) {
    if ((0, _anyIsPromise.default)(any)) {
      return any.then(resolved => anyResolveWith(resolved, func));
    }

    if ((0, _anyIsGenerator.default)(any) || (0, _anyIsOp.default)(any)) {
      return (0, _anyResolveToGeneratorWith.default)(any, func);
    }

    any = (0, _anyResolve.default)(any);
  }

  return (0, _anyResolve.default)(func(any));
};

var _default = anyResolveWith;
exports.default = _default;
//# sourceMappingURL=anyResolveWith.js.map