"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Number = require("../constants/Number");

var _anyToNumber = _interopRequireDefault(require("./anyToNumber"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Converts `any` to a finite number.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to convert.
 * @returns {number} Returns the converted number.
 * @example
 *
 * anyToFinite(3.2)
 * //=> 3.2
 *
 * anyToFinite(Number.MIN_VALUE)
 * //=> 5e-324
 *
 * anyToFinite(Infinity)
 * //=> 1.7976931348623157e+308
 *
 * anyToFinite('3.2')
 * //=> 3.2
 */
var anyToFinite = any => {
  if (!any) {
    return any === 0 ? any : 0;
  }

  any = (0, _anyToNumber.default)(any);

  if (any === _Number.INFINITY || any === -_Number.INFINITY) {
    var sign = any < 0 ? -1 : 1;
    return sign * _Number.MAX_VALUE;
  }

  return any === any ? any : 0;
};

var _default = anyToFinite;
exports.default = _default;
//# sourceMappingURL=anyToFinite.js.map