"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Iterator = require("../constants/Iterator");

var _Symbol = require("../constants/Symbol");

var _anyIsArrayLike = _interopRequireDefault(require("./anyIsArrayLike"));

var _anyIsIndexedIterator = _interopRequireDefault(require("./anyIsIndexedIterator"));

var _anyIsIterable = _interopRequireDefault(require("./anyIsIterable"));

var _anyIsIterator = _interopRequireDefault(require("./anyIsIterator"));

var _anyIsKeyedIterator = _interopRequireDefault(require("./anyIsKeyedIterator"));

var _anyIsObjectLike = _interopRequireDefault(require("./anyIsObjectLike"));

var _arrayLikeToIterator = _interopRequireDefault(require("./arrayLikeToIterator"));

var _iteratorResolver = _interopRequireDefault(require("./iteratorResolver"));

var _objectToIterator = _interopRequireDefault(require("./objectToIterator"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * This method generates an iterator for the given value
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param  {*} any The collection or iterator to iterate over
 * @param  {string} start The position to start at for iteration
 * @returns {Iterator} The Iterator for the given value
 * @example
 *
 * anyToIterator(['a', 'b', 'c'])
 * //=> { next: () => { value: string, index: number, kdx: umber, done: boolean }}
 *
 * anyToIterator('abc')
 * //=> { next: () => { value: string, index: number, kdx: umber, done: boolean }}
 *
 * anyToIterator({ a: 1, b: 2, c: 3 })
 * //=> { next: () => { value: number, key: string, kdx: string, done: boolean }}
 */
var anyToIterator = (any, start = _Iterator.START) => {
  if ((0, _anyIsIterator.default)(any)) {
    if ((0, _anyIsIndexedIterator.default)(any) || (0, _anyIsKeyedIterator.default)(any) || any.resolver) {
      return any;
    }

    return (0, _iteratorResolver.default)(any, start);
  }

  if ((0, _anyIsArrayLike.default)(any)) {
    return (0, _arrayLikeToIterator.default)(any, start);
  }

  if ((0, _anyIsIterable.default)(any)) {
    return (0, _iteratorResolver.default)(any[_Symbol.ITERATOR](), start);
  }

  if ((0, _anyIsObjectLike.default)(any)) {
    return (0, _objectToIterator.default)(any, start);
  }

  throw new Error("iterator method expected to receive an iterable value. Instead the method was given ".concat(any, "."));
};

var _default = anyToIterator;
exports.default = _default;
//# sourceMappingURL=anyToIterator.js.map