"use strict";

require("core-js/modules/es.array.slice");

require("core-js/modules/es.string.replace");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _NaN = _interopRequireDefault(require("../classes/NaN"));

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

var _anyIsObject = _interopRequireDefault(require("./anyIsObject"));

var _anyIsSymbol = _interopRequireDefault(require("./anyIsSymbol"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** Used to match leading and trailing whitespace. */
var reTrim = /^\s+|\s+$/g;
/** Used to detect bad signed hexadecimal string values. */

var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;
/** Used to detect binary string values. */

var reIsBinary = /^0b[01]+$/i;
/** Used to detect octal string values. */

var reIsOctal = /^0o[0-7]+$/i;
/** Built-in method references without a dependency on `root`. */

var freeParseInt = parseInt;
/**
 * Converts `any` to a `Number`.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to process.
 * @returns {number} Returns the number.
 * @example
 *
 * anyToNumber(3.2)
 * // => 3.2
 *
 * anyToNumber(Number.MIN_VALUE)
 * // => 5e-324
 *
 * anyToNumber(Infinity)
 * // => Infinity
 *
 * anyToNumber('3.2')
 * // => 3.2
 */

var anyToNumber = any => {
  if (any != null && (0, _anyIsFunction.default)(any.toNumber)) {
    return any.toNumber();
  }

  if (typeof any == 'number') {
    return any;
  }

  if ((0, _anyIsSymbol.default)(any)) {
    return _NaN.default;
  }

  if ((0, _anyIsObject.default)(any)) {
    var other = typeof any.valueOf == 'function' ? any.valueOf() : any;
    any = (0, _anyIsObject.default)(other) ? "".concat(other) : other;
  }

  if (typeof any != 'string') {
    return any === 0 ? any : +any;
  }

  any = any.replace(reTrim, '');
  var isBinary = reIsBinary.test(any);
  return isBinary || reIsOctal.test(any) ? freeParseInt(any.slice(2), isBinary ? 2 : 8) : reIsBadHex.test(any) ? _NaN.default : +any;
};

var _default = anyToNumber;
exports.default = _default;
//# sourceMappingURL=anyToNumber.js.map