"use strict";

require("core-js/modules/es.array.slice");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _objectToString = _interopRequireDefault(require("./objectToString"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Gives a single-word string description of the (native) type of a value,
 * returning such answers as 'Object', 'Number', 'Array', or 'Null'. Does not
 * attempt to distinguish user Object types any further, reporting them all as
 * 'Object'.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} value The value to test
 * @returns {string}
 * @example
 *
 * anyToStringTag({})
 * //=> 'Object'
 *
 * anyToStringTag(1)
 * //=> 'Number'
 *
 * anyToStringTag(false)
 * //=> 'Boolean'
 *
 * anyToStringTag('s')
 * //=> 'String'
 *
 * anyToStringTag(null)
 * //=> 'Null'
 *
 * anyToStringTag([])
 * //=> 'Array'
 *
 * toType(/[A-z]/)
 * //=> 'RegExp'
 *
 * anyToStringTag(() => {})
 * //=> 'Function'
 *
 * anyToStringTag(undefined)
 * //=> 'Undefined'
 */
var anyToStringTag = any => {
  return any === null ? 'Null' : any === undefined ? 'Undefined' : (0, _objectToString.default)(any).slice(8, -1);
};

var _default = anyToStringTag;
exports.default = _default;
//# sourceMappingURL=anyToStringTag.js.map