"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _ImmutableSet = _interopRequireDefault(require("../classes/ImmutableSet"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns an `Array` of all elements in the first `Array` not contained in the
 * second `Array`.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Array} array The array concat with the given values
 * @param {...*} values The values to concat to the array
 * @returns {Array} A new array with the values concatenated
 * @example
 *
 * arrayConcat(['a', 'b', 'c'], [1, 2, 3])
 * //=> ['a', 'b', 'c', 1, 2, 3]
 *
 * arrayConcat([1, 2, 3], [4, 5, 6], [7, 8, 9])
 * //=> [1, 2, 3, 4, 5, 6, 7, 8, 9]
 *
 * arrayConcat(['a', 'b', 'c'], 1, [2, 3])
 * //=> ['a', 'b', 'c', 1, 2, 3]
 */
var arrayDifference = (array, second) => {
  var result = [];
  var length = array.length;
  var filterSet = (0, _ImmutableSet.default)(second);
  var idx = 0;

  while (idx < length) {
    if (!filterSet.has(array[idx])) {
      result.push(array[idx]);
    }

    idx += 1;
  }

  return result;
};

var _default = arrayDifference;
exports.default = _default;
//# sourceMappingURL=arrayDifference.js.map