"use strict";

require("core-js/modules/es.array.filter");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Array = _interopRequireDefault(require("../classes/Array"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var filter = _Array.default.prototype.filter;
/**
 * This method creates a new `Array` with all elements that pass the test implemented by the provided function.
 *
 * See [Array.prototype.filter()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/filter) for more information
 *
 * @private
 * @function
 * @since v0.2.0
 * @category lang.util
 * @template T
 * @param {Array} array The array to iterate over.
 * @param {Function} predicate The function to execute for each element
 * @returns {Array} A new Array with the values that passed the given predicate test
 * @example
 *
 * const words = ['spray', 'limit', 'elite', 'exuberant', 'destruction', 'present']
 *
 * const result = arrayFilter(words, (word) => word.length > 6)
 *
 * console.log(result)
 * // => expected output: Array ["exuberant", "destruction", "present"]
 */

var arrayFilter = (array, predicate) => filter.call(array, predicate);

var _default = arrayFilter;
exports.default = _default;
//# sourceMappingURL=arrayFilter.js.map