"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsArray = _interopRequireDefault(require("./anyIsArray"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns a new array by pulling every item out of it (and all its sub-arrays) and putting them in a new array, depth-first.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Array} array The array to consider.
 * @returns {Array} The flattened list.
 * @example
 *
 * arrayFlatten([1, 2, [3, 4], 5, [6, [7, 8, [9, [10, 11], 12]]]])
 * //=> [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
 */
var arrayFlatten = (list, recur = arrayFlatten) => {
  var result = [];
  var ilen = list.length;
  var idx = 0;

  while (idx < ilen) {
    var item = list[idx];

    if ((0, _anyIsArray.default)(item) && list !== item) {
      var value = recur ? recur(item, recur) : item;
      var idxj = 0;
      var jlen = value.length;

      while (idxj < jlen) {
        result[result.length] = value[idxj];
        idxj += 1;
      }
    } else {
      result[result.length] = list[idx];
    }

    idx += 1;
  }

  return result;
};

var _default = arrayFlatten;
exports.default = _default;
//# sourceMappingURL=arrayFlatten.js.map