"use strict";

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Array = _interopRequireDefault(require("../classes/Array"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var forEach = _Array.default.prototype.forEach;
/**
 * This method executes a provided function once for each array element.
 *
 * See [Array.prototype.forEach()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/forEach) for more information
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @template T
 * @param {T[]} array The array to iterate over.
 * @param {Function} func The function to execute for each element
 * @returns {T[]} The original array
 * @example
 *
 * const items = ['item1', 'item2', 'item3']
 * const copy = []
 *
 * for (let i=0; i<items.length; i++) {
 *   copy.push(items[i])
 * }
 * //=> ['item1', 'item2', 'item3']
 */

var arrayForEach = (array, func) => forEach.call(array, func);

var _default = arrayForEach;
exports.default = _default;
//# sourceMappingURL=arrayForEach.js.map