"use strict";

require("core-js/modules/es.array.index-of");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsFunction = _interopRequireDefault(require("./anyIsFunction"));

var _anyIsNaN = _interopRequireDefault(require("./anyIsNaN"));

var _anyToStringTag = _interopRequireDefault(require("./anyToStringTag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var arrayIndexOfAtIndex = (array, value, index, equalsFunc) => {
  var inf;
  var item;
  var length = array.length; // Array.prototype.indexOf doesn't exist below IE9

  if ((0, _anyIsFunction.default)(array.indexOf)) {
    switch ((0, _anyToStringTag.default)(value)) {
      case 'Number':
        if (value === 0) {
          // manually crawl the list to distinguish between +0 and -0
          inf = 1 / value;

          while (index < length) {
            item = array[index];

            if (item === 0 && 1 / item === inf) {
              return index;
            }

            index += 1;
          }

          return -1;
        } else if ((0, _anyIsNaN.default)(value)) {
          while (index < array.length) {
            item = array[index];

            if ((0, _anyIsNaN.default)(item)) {
              return index;
            }

            index += 1;
          }

          return -1;
        } // non-zero numbers can utilise Set


        return array.indexOf(value, index);
      // all these types can utilise Set

      case 'String':
      case 'Boolean':
      case 'Function':
      case 'Undefined':
        return array.indexOf(value, index);

      case 'Null':
        // null can utilise Set
        return array.indexOf(value, index);
    }
  } // anything else not covered above, defer to R.equals


  while (index < length) {
    if (equalsFunc(array[index], value)) {
      return index;
    }

    index += 1;
  }

  return -1;
};

var _default = arrayIndexOfAtIndex;
exports.default = _default;
//# sourceMappingURL=arrayIndexOfAtIndex.js.map