"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Array = _interopRequireDefault(require("../classes/Array"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var keys = _Array.default.prototype.keys;
/**
 * This method returns a new Array Iterator object that contains the keys for each index in the array.
 *
 * See [Array.prototype.keys()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/keys) for more information
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Array} array The array whose indexes to iterate over.
 * @returns {Iterator<Index>} Iterator of the Array's Indexes
 * @example
 *
 * const array1 = ['a', 'b', 'c'];
 * const iterator = array1.keys();
 *
 * for (const key of iterator) {
 *   console.log(key)
 * }
 * // => expected output: 0
 * // => expected output: 1
 * // => expected output: 2
 */

var arrayKeys = (array, func) => keys.call(array, func);

var _default = arrayKeys;
exports.default = _default;
//# sourceMappingURL=arrayKeys.js.map