"use strict";

require("core-js/modules/es.array.filter");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Iterator = require("../constants/Iterator");

var _indexEndOffset = _interopRequireDefault(require("./indexEndOffset"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var iterAt = (index, arrayLike) => {
  if (index < arrayLike.length && index >= 0) {
    return {
      done: false,
      index,
      kdx: index,
      value: arrayLike[index]
    };
  }

  return {
    done: true
  };
};

var prevIterAt = (index, arrayLike) => {
  if (index < arrayLike.length && index >= 0) {
    return {
      done: false,
      index,
      kdx: index,
      value: arrayLike[index]
    };
  }
};
/**
 * Returns iterator for an array like value.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} arrayLike The array like value to create an iterator for.
 * @param {*} index The index to start at.
 * @return {IndexedIterator} A new iterator for the given array like value
 * @example
 *
 * arrayLikeToIterator(['write', 'more'])
 * //=> {
 * //   next: () => ({
 * //     value: *,
 * //     done: boolean,
 * //     kdx: integer,
 * //     index: integer
 * //   }),
 * //   previous: () => ({
 * //     value: *,
 * //     done: boolean,
 * //     kdx: integer,
 * //     index: integer
 * //   })
 * // }
 * arrayLikeToIterator('tests')
 * //=> {
 * //   next: () => ({
 * //     value: *,
 * //     done: boolean,
 * //     kdx: integer,
 * //     index: integer
 * //   })
 * //   previous: () => ({
 * //     value: *,
 * //     done: boolean,
 * //     kdx: integer,
 * //     index: integer
 * //   })
 * // }
 */


var arrayLikeToIterator = (arrayLike, index = 0) => {
  if (index === _Iterator.END) {
    index = arrayLike.length;
  } else if (index === _Iterator.START) {
    index = 0;
  }

  index = (0, _indexEndOffset.default)(index, arrayLike.length);
  var lastIndex;
  return {
    getIndex: () => lastIndex,
    next: () => {
      var iter = iterAt(index, arrayLike);
      var prev = prevIterAt(index - 1, arrayLike);

      if (index < arrayLike.length) {
        lastIndex = index;
        index += 1;
      }

      return _objectSpread(_objectSpread({}, iter), {}, {
        prev
      });
    },
    previous: () => {
      var iter = iterAt(index - 1, arrayLike);
      var prev = prevIterAt(index, arrayLike);

      if (index >= 0) {
        lastIndex = index - 1;
        index -= 1;
      }

      return _objectSpread(_objectSpread({}, iter), {}, {
        prev
      });
    }
  };
};

var _default = arrayLikeToIterator;
exports.default = _default;
//# sourceMappingURL=arrayLikeToIterator.js.map