"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _cacheChain = _interopRequireDefault(require("./cacheChain"));

var _functionMemoizeWith = _interopRequireDefault(require("./functionMemoizeWith"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Creates a new function that, when invoked, caches the result of calling
 * `func` for a given argument set and returns the result. Subsequent calls to
 * the memoized `func` with the same argument set will not result in an additional
 * call to `func`; instead, the cached result for that set of arguments will be
 * returned.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Function} func The function to memoize.
 * @return {Function} Memoized version of `func`.
 * @example
 *
 * let count = 0
 * const factorial = memoize(n => {
 *   count += 1
 *   return product(range(1, n + 1))
 * })
 * factorial(5)
 * //=> 120
 *
 * factorial(5)
 * //=> 120
 *
 * factorial(5)
 * //=> 120
 *
 * count
 * //=> 1
 */
var functionMemoize = func => (0, _functionMemoizeWith.default)(func, _cacheChain.default);

var _default = functionMemoize;
exports.default = _default;
//# sourceMappingURL=functionMemoize.js.map