"use strict";

require("core-js/modules/es.array.filter");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Function = require("../constants/Function");

var _Iterator = require("../constants/Iterator");

var _anyIsResolved = _interopRequireDefault(require("./anyIsResolved"));

var _anyResolveWith = _interopRequireDefault(require("./anyResolveWith"));

var _unresolvedResolveWith = _interopRequireDefault(require("./unresolvedResolveWith"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var iterateAt = (iterator, history, pending, index, withFunc) => {
  if (history[index]) {
    return history[index];
  }

  if (pending[index]) {
    return pending[index];
  }

  var next = iterator.next();
  pending[index] = next;
  history[index] = null;
  return (0, _anyResolveWith.default)(next, resolvedNext => {
    resolvedNext = withFunc(resolvedNext);
    pending[index] = null;

    if (!resolvedNext.done) {
      history[index] = resolvedNext;
    }

    return resolvedNext;
  });
};

var fastForward = histIterator => {
  var next = {
    done: false
  };

  while (!next.done) {
    next = histIterator.next();

    if (!(0, _anyIsResolved.default)(next)) {
      return (0, _unresolvedResolveWith.default)(next, resolvedNext => {
        if (!resolvedNext.done) {
          return fastForward(histIterator);
        }

        return histIterator;
      });
    }
  }

  return histIterator;
};

var iterAt = (index, history) => {
  if (index >= 0 && history[index]) {
    var iter = history[index];
    return _objectSpread({
      index,
      kdx: index
    }, iter);
  }

  return {
    done: true
  };
};

var prevIterAt = (index, history) => {
  if (index >= 0 && history[index]) {
    var iter = history[index];
    return _objectSpread({
      index,
      kdx: index
    }, iter);
  }
};

var historicIterator = (iterator, start, withFunc) => {
  var history = [];
  var pending = [];
  var index = 0;
  var histIterator = {
    next: () => {
      var iter = iterateAt(iterator, history, pending, index, withFunc);
      return (0, _anyResolveWith.default)(iter, resolvedIter => {
        var prev = prevIterAt(index - 1, history);

        if (!resolvedIter.done) {
          resolvedIter = iterAt(index, history);
          index += 1;
        }

        return _objectSpread(_objectSpread({}, resolvedIter), {}, {
          prev
        });
      });
    },
    previous: () => {
      var iter = iterAt(index - 1, history);
      var prev = prevIterAt(index, history);

      if (index >= 0) {
        index -= 1;
      }

      return _objectSpread(_objectSpread({}, iter), {}, {
        prev
      });
    }
  };

  if (start === _Iterator.END) {
    return fastForward(histIterator);
  }

  return histIterator;
};
/**
 * Returns iterator capable of resolving iterators that might be async, wrapping it in additional functionality.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Iterator} iterator The iterator to wrap
 * @param {string} start The positin to start at.
 * @return {Iterator} A new iterator for the given iterator
 * @example
 *
 * iteratorResolver(
 *  (['write', 'more'])[Symbol.iterator]()
 * )
 * //=> {
 * //   next: () => ({
 * //     value: *,
 * //     done: boolean,
 * //     kdx: integer,
 * //     index: integer
 * //   }),
 * //   previous: () => ({
 * //     value: *,
 * //     done: boolean,
 * //     kdx: integer,
 * //     index: integer
 * //   })
 * // }
 */


var iteratorResolver = (iterator, start = _Iterator.START, withFunc = _Function.IDENTITY) => {
  // NOTE BRN: Optimization here of reassigning histIterator so that we don't have to resolve it on every iteration.
  var histIterator;
  histIterator = (0, _anyResolveWith.default)(historicIterator(iterator, start, withFunc), resolvedIterator => {
    histIterator = resolvedIterator;
    return histIterator;
  }); // TODO BRN: Figure out a more efficient way of doing this rather than
  // resolving the iterator every time

  return {
    next: () => (0, _anyResolveWith.default)(histIterator, resolvedIterator => resolvedIterator.next()),
    previous: () => (0, _anyResolveWith.default)(histIterator, resolvedIterator => resolvedIterator.previous()),
    resolver: true
  };
};

var _default = iteratorResolver;
exports.default = _default;
//# sourceMappingURL=iteratorResolver.js.map