"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _objectClone = _interopRequireDefault(require("./objectClone"));

var _objectHasOwnProperty = _interopRequireDefault(require("./objectHasOwnProperty"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Removes a property from an Object. Returns a copy of the object with the
 * Property removed.
 *
 * See [delete operator](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/delete) for more information
 *
 * @private
 * @function
 * @immutable
 * @pure
 * @since v0.1.0
 * @category lang.util
 * @param {Object} object The Object on which to remove the property.
 * @param {String} prop The name or Symbol of the property to be deleted.
 * @returns {Object} A copy of the Object that was passed to the function.
 * @example
 *
 * const object = {
 *   foo: 1,
 *   bar: 2
 * }
 *
 * const result = objectDeleteProperty(object, 'foo')
 *
 * result.foo
 * //=> undefined
 * object.foo
 * //=> 1
 */
var objectDeleteProperty = (object, property) => {
  if (!(0, _objectHasOwnProperty.default)(object, property)) {
    return object;
  }

  var clone = (0, _objectClone.default)(object);
  delete clone[property];
  return clone;
};

var _default = objectDeleteProperty;
exports.default = _default;
//# sourceMappingURL=objectDeleteProperty.js.map