"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Object = _interopRequireDefault(require("../classes/Object"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Returns an array of all symbol properties found directly upon a given object.
 *
 * See [Object.getOwnPropertySymbols()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/getOwnPropertySymbols) for more information
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Object} object The object whose symbol properties are to be returned.
 * @returns {Array} An array of all symbol properties found directly upon the given object.
 * @example

 * const object1 = {}
 * const a = Symbol('a')
 * const b = Symbol.for('b')
 *
 * object1[a] = 'localSymbol'
 * object1[b] = 'globalSymbol'
 *
 * const objectSymbols = objectGetOwnPropertySymbols(object1)
 *
 * console.log(objectSymbols.length)
 * //=>  2
 */
var objectGetOwnPropertySymbols = object => {
  if (typeof _Object.default.getOwnPropertySymbols === 'function') {
    return _Object.default.getOwnPropertySymbols(object);
  }

  return [];
};

var _default = objectGetOwnPropertySymbols;
exports.default = _default;
//# sourceMappingURL=objectGetOwnPropertySymbols.js.map