"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Object = _interopRequireDefault(require("../classes/Object"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var hasOwnProperty = _Object.default.prototype.hasOwnProperty;
/**
 * Returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).
 *
 * See [Object.hasOwnProperty()](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/hasOwnProperty) for more information
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {Object} object The object on which to check for the property.
 * @param {Property} property The String name or symbol of the property to test.
 * @returns {Boolean} A boolean indicating whether or not the object has the specified property as own property.
 * @example
 *
 * const object = new Object()
 * object.property1 = 42
 *
 * objectHasOwnProperty(object, 'property1')
 * //=> true
 *
 * objectHasOwnProperty(object, 'toString')
 * //=> false
 *
 * objectHasOwnProperty(object, 'hasOwnProperty')
 * //=> false
 */

var objectHasOwnProperty = (object, property) => hasOwnProperty.call(object, property);

var _default = objectHasOwnProperty;
exports.default = _default;
//# sourceMappingURL=objectHasOwnProperty.js.map