"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _objectMutateSetProperty = _interopRequireDefault(require("./objectMutateSetProperty"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Updates a `Property` on an `Object`
 *
 * @private
 * @function
 * @mutable
 * @since v0.2.0
 * @category lang.util
 * @param {Object} object The Object on which to update the property.
 * @param {Property} property The name or Symbol of the property to update.
 * @param {Function} func The updater Function
 * @returns {Object} The original Object with the Property updated with the
 * result of the updater function
 *
 * const object = {
 *   foo: 1,
 *   bar: 2
 * }
 *
 * const result = objectMutateUpdateProperty(object, 'foo', (value) => value + 1)
 *
 * result.foo
 * //=> 2
 *
 * object.foo
 * //=> 2
 */
var objectMutateUpdateProperty = (object, property, func) => {
  var result = func(object[property]);
  return (0, _objectMutateSetProperty.default)(object, property, result);
};

var _default = objectMutateUpdateProperty;
exports.default = _default;
//# sourceMappingURL=objectMutateUpdateProperty.js.map