"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIdenticalWithAny = _interopRequireDefault(require("./anyIdenticalWithAny"));

var _objectClone = _interopRequireDefault(require("./objectClone"));

var _objectHasOwnProperty = _interopRequireDefault(require("./objectHasOwnProperty"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Sets a `Property` on an `Object` and returns a copy of the `Object` with the
 * `Property` set. If the property's value is set to the same value, then the
 * same instance of Object will be returned with no changes.
 *
 * @private
 * @function
 * @immutable
 * @pure
 * @since v0.1.0
 * @category lang.util
 * @param {Object} object The Object on which to set the property.
 * @param {Property} property The name or Symbol of the property to update.
 * @param {Any} value The value to set the Property to
 * @returns {Object} A copy of the Object with the Property set to the new value
 *
 * const object = {
 *   foo: 1,
 *   bar: 2
 * }
 *
 * const result = objectSetProperty(object, 'foo', 3)
 *
 * result.foo
 * //=> 3
 *
 * object.foo
 * //=> 1
 */
var objectSetProperty = (object, property, value) => {
  if ((0, _anyIdenticalWithAny.default)(value, object[property]) && (0, _objectHasOwnProperty.default)(object, property)) {
    return object;
  }

  var clone = (0, _objectClone.default)(object);
  clone[property] = value;
  return clone;
};

var _default = objectSetProperty;
exports.default = _default;
//# sourceMappingURL=objectSetProperty.js.map