"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _anyIsGenerator = _interopRequireDefault(require("./anyIsGenerator"));

var _anyIsOp = _interopRequireDefault(require("./anyIsOp"));

var _anyIsPromise = _interopRequireDefault(require("./anyIsPromise"));

var _anyResolveWith = _interopRequireDefault(require("./anyResolveWith"));

var _generatorResolveToGeneratorWith = _interopRequireDefault(require("./generatorResolveToGeneratorWith"));

var _opResolveToGeneratorWith = _interopRequireDefault(require("./opResolveToGeneratorWith"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Resolves an unresolved value to the given method.
 *
 * If the value to be resolved is a promise then this method will return a promise. The fn method will be triggered once the promise resolves.
 *
 * If the value to be resolved is a generator, this method will return a generator.
 *
 * @private
 * @function
 * @since v0.1.0
 * @category lang.util
 * @param {*} any The value to resolve with the generator
 * @param {Function} func The function to execute at the end of the resolution
 * @returns {Generator}
 * @example
 *
 * await unresolvedResolveWith(
 *   Promise.resolve('foo'),
 *   (resolvedValue) => 'bar' // resolvedValue == 'foo'
 * )
 * //=> 'bar'
 */
var unresolvedResolveWith = (unresolved, func) => {
  if ((0, _anyIsPromise.default)(unresolved)) {
    return unresolved.then(resolved => (0, _anyResolveWith.default)(resolved, func));
  }

  if ((0, _anyIsGenerator.default)(unresolved)) {
    return (0, _generatorResolveToGeneratorWith.default)(unresolved, func);
  }

  if ((0, _anyIsOp.default)(unresolved)) {
    return (0, _opResolveToGeneratorWith.default)(unresolved, func);
  }

  return (0, _anyResolveWith.default)(unresolved.resolve(), func);
};

var _default = unresolvedResolveWith;
exports.default = _default;
//# sourceMappingURL=unresolvedResolveWith.js.map