"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _curryN = _interopRequireDefault(require("./curryN"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Walk using the given walkee and iteratee functions.
 *
 * @function
 * @since v0.0.4
 * @category lang
 * @param {Function} walkee The function responsible for returning the next value in the walk
 * @param {Function} iteratee The iterator function.
 * @returns {*} The final value returned by the walk
 * @example
 *
 * const depthFirstWalkee = (value, iteratee, recur) => {
 *   if (isObject(value)) {
 *     forEachObjIndexed((child) => {
 *       recur(child, iteratee)
 *     }, value)
 *   }
 *   iteratee(value, data)
 * }
 * let result = []
 * walk(
 *   depthFirstWalkee,
 *   (value) => result.push(value),
 *   {
 *     a: {
 *       b: 'b'
 *     }
 *   }
 * )
 * console.log(result)
 * //=> [
 *   'b',
 *   { b: 'b' },
 *   { a: { b: 'b' } }
 * ]
 */
var walk = (0, _curryN.default)(2, (walkee, ...args) => {
  var walker = (...pass) => walkee(...pass, walker);

  return walkee(...args, walker);
});
var _default = walk;
exports.default = _default;
//# sourceMappingURL=walk.js.map