"use strict";

require("core-js/modules/es.array.iterator");

require("core-js/modules/es.set");

require("core-js/modules/web.dom-collections.iterator");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _concat = _interopRequireDefault(require("./concat"));

var _defn = _interopRequireDefault(require("./defn"));

var _isObjectLike = _interopRequireDefault(require("./isObjectLike"));

var _pipe = _interopRequireDefault(require("./pipe"));

var _reduce = _interopRequireDefault(require("./reduce"));

var _resolve = _interopRequireDefault(require("./resolve"));

var _walk = _interopRequireDefault(require("./walk"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var reduceWalkee = () => {
  var visited = new Set();
  return (iteratee, accum, value, keys, recur) => {
    var resolvedValue = (0, _resolve.default)(value);
    return (0, _pipe.default)(result => {
      if ((0, _isObjectLike.default)(resolvedValue) && !visited.has(resolvedValue)) {
        visited.add(resolvedValue);
        return (0, _reduce.default)((accumResult, child, childKdx) => {
          var newKeys = (0, _concat.default)(keys, [childKdx]);
          return recur(iteratee, accumResult, child, newKeys);
        }, result, resolvedValue);
      }

      return result;
    }, result => iteratee(result, value, keys))(accum);
  };
};
/**
 * Walk depth first and reduce using the given reducer function
 *
 * NOTE: This method will resolve values during the walk before iterating and walking them.
 *
 * @function
 * @since v0.0.4
 * @category lang
 * @param {Function} iteratee The iterator function. Receives three values, the accumulator and the current element from the walk and the current set of keys from the entire depth of the walk.
 * @param {*} accum The accumulator value.
 * @param {*} collection The collection to walk.
 * @returns {*} The final, accumulated value.
 * @example
 *
 * walkReduceDepthFirst(
 *   (accum, value, keys) => {
 *     accum.push(keys)
 *     return accum
 *   },
 *   [],
 *   {
 *     a: {
 *       b: {
 *         c: 'c'
 *       },
 *       d: 'd',
 *     },
 *     e: [ 'e', 'f' ]
 *   }
 * )
 * //=> [
 *   [ 'a', 'b', 'c' ],
 *   [ 'a', 'b' ],
 *   [ 'a', 'd' ],
 *   [ 'a' ],
 *   [ 'e', 0 ],
 *   [ 'e', 1 ],
 *   [ 'e' ],
 *   []
 * ]
 */


var walkReduceDepthFirst = (0, _defn.default)('walkReduceDepthFirst', (iteratee, accum, collection) => (0, _walk.default)(reduceWalkee(), iteratee, accum, collection, []));
var _default = walkReduceDepthFirst;
exports.default = _default;
//# sourceMappingURL=walkReduceDepthFirst.js.map