"use strict";

require("core-js/modules/es.array.filter");

require("core-js/modules/es.object.get-own-property-descriptors");

require("core-js/modules/web.dom-collections.for-each");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _curry = _interopRequireDefault(require("./curry"));

var _getPath = _interopRequireDefault(require("./getPath"));

var _hasPath = _interopRequireDefault(require("./hasPath"));

var _isObject = _interopRequireDefault(require("./isObject"));

var _iterate = _interopRequireDefault(require("./iterate"));

var _resolveWith = _interopRequireDefault(require("./resolveWith"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Takes a spec object and a test object; returns true if the test satisfies
 * the spec. Each of the spec's own properties must be a predicate function.
 * Each predicate is applied to the value of the corresponding property of the
 * test object. `where` returns true if all the predicates return true, false
 * otherwise.
 *
 * `where` is well suited to declaratively expressing constraints for other
 * functions such as [`filter`](#filter) and [`find`](#find).
 *
 * @function
 * @since v0.4.3
 * @category lang
 * @param {Object} spec
 * @param {Any} value
 * @return {Boolean}
 * @example
 *
 *      // pred :: Object -> Boolean
 *      const pred = where({
 *        a: equals('foo'),
 *        b: complement(equals('bar')),
 *        x: gt(__, 10),
 *        y: lt(__, 20)
 *      });
 *
 *      pred({a: 'foo', b: 'xxx', x: 11, y: 19}); //=> true
 *      pred({a: 'xxx', b: 'xxx', x: 11, y: 19}); //=> false
 *      pred({a: 'foo', b: 'bar', x: 11, y: 19}); //=> false
 *      pred({a: 'foo', b: 'xxx', x: 10, y: 19}); //=> false
 *      pred({a: 'foo', b: 'xxx', x: 11, y: 20}); //=> false
 */
var where = (0, _curry.default)((spec, value) => {
  if (!(0, _isObject.default)(value)) {
    return false;
  }

  return (0, _iterate.default)(next => {
    if (next.done) {
      return _objectSpread(_objectSpread({}, next), {}, {
        value: true
      });
    }

    if (!(0, _hasPath.default)(next.kdx, value)) {
      return _objectSpread(_objectSpread({}, next), {}, {
        done: true,
        value: false
      });
    }

    return (0, _resolveWith.default)(nextValue => {
      if (!next.value(nextValue)) {
        return _objectSpread(_objectSpread({}, next), {}, {
          done: true,
          value: false
        });
      }

      return next;
    }, (0, _getPath.default)(next.kdx, value));
  }, spec);
});
var _default = where;
exports.default = _default;
//# sourceMappingURL=where.js.map