"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _curry = _interopRequireDefault(require("./curry"));

var _equals = _interopRequireDefault(require("./equals"));

var _map = _interopRequireDefault(require("./map"));

var _where = _interopRequireDefault(require("./where"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Takes a spec object and a test object; returns true if the test satisfies
 * the spec, false otherwise. An object satisfies the spec if, for each of the
 * spec's own properties, accessing that property of the object gives the same
 * value (in [`equals`](#equals) terms) as accessing that property of the
 * spec.
 *
 * @function
 * @since v0.4.3
 * @category lang
 * @param {Object} spec
 * @param {Any} value
 * @return {Boolean}
 * @example
 *
 *      // pred :: Object -> Boolean
 *      const pred = R.whereEq({a: 1, b: 2});
 *
 *      pred({a: 1});              //=> false
 *      pred({a: 1, b: 2});        //=> true
 *      pred({a: 1, b: 2, c: 3});  //=> true
 *      pred({a: 1, b: 1});        //=> false
 */
var whereEquals = (0, _curry.default)((spec, value) => (0, _where.default)((0, _map.default)(specValue => (0, _equals.default)(specValue), spec), value));
var _default = whereEquals;
exports.default = _default;
//# sourceMappingURL=whereEquals.js.map