import Infinity from '../classes/Infinity'
import Number from '../classes/Number'

/**
 * This constant represents the value Infinity in JavaScript `Infinity`
 *
 * See
 * [Infinity](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Infinity)
 * for more information.
 *
 * @private
 * @type {number}
 * @since v0.1.0
 * @category lang.constants
 */
export const INFINITY = Infinity

/**
 * This constant property represents the maximum numeric value representable in JavaScript (1.7976931348623157e+308)
 *
 * See [Number.MAX_VALUE](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Number/MAX_VALUE) for more information.
 *
 * @private
 * @type {number}
 * @since v0.1.0
 * @category lang.constants
 */
export const { MAX_VALUE } = Number
